clixx.types
===========

.. currentmodule:: clixx.types

Classes
-------

.. autoclass:: Type
    :members:
    :special-members: __call__
    :show-inheritance:

.. autoclass:: Str
    :members:
    :show-inheritance:

.. autoclass:: Bool
    :members:
    :show-inheritance:

.. autoclass:: Int
    :members:
    :show-inheritance:

.. autoclass:: Float
    :members:
    :show-inheritance:

.. autoclass:: Choice
    :members:
    :show-inheritance:

.. autoclass:: IntChoice
    :members:
    :show-inheritance:

.. autoclass:: Enum
    :members:
    :show-inheritance:

.. autoclass:: IntEnum
    :members:
    :show-inheritance:

.. autoclass:: DateTime
    :members:
    :show-inheritance:

.. autoclass:: File
    :members:
    :show-inheritance:

.. autoclass:: Path
    :members:
    :show-inheritance:

.. autoclass:: DirPath
    :members:
    :show-inheritance:

.. autoclass:: FilePath
    :members:
    :show-inheritance:

Functions
---------

.. autofunction:: resolve_type
